@@ -1,7 +1,7 @@
 package Calendar::Indonesia::Holiday;
 
-our $DATE = '2015-04-28'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2015-07-25'; # DATE
+our $VERSION = '0.25'; # VERSION
 
 use 5.010001;
 use strict;
@@ -579,8 +579,8 @@ $year_holidays{2014} = [
         _h_pelection ({_expand_dm("09-07")}, {}),
     ),
     ($eidulf2014 =
-    _h_eidulf    ({_expand_dm("28-07")}, {hyear=>1435, day=>1}),
-    _h_eidulf    ({_expand_dm("29-07")}, {hyear=>1435, day=>2})),
+    _h_eidulf    ({_expand_dm("28-07")}, {hyear=>1435, day=>1})),
+    _h_eidulf    ({_expand_dm("29-07")}, {hyear=>1435, day=>2}),
     ($eidula2014 =
     _h_eidula    ({_expand_dm("05-10")}, {hyear=>1435})),
     _h_hijra     ({_expand_dm("25-10")}, {hyear=>1436}),
@@ -608,8 +608,8 @@ $year_holidays{2015} = [
     _h_vesakha   ({_expand_dm("02-06")}, {hyear=>2559}),
 
     ($eidulf2015 =
-    _h_eidulf    ({_expand_dm("17-07")}, {hyear=>1436, day=>1}),
-    _h_eidulf    ({_expand_dm("18-07")}, {hyear=>1436, day=>2})),
+    _h_eidulf    ({_expand_dm("17-07")}, {hyear=>1436, day=>1})),
+    _h_eidulf    ({_expand_dm("18-07")}, {hyear=>1436, day=>2}),
     _h_eidula    ({_expand_dm("24-09")}, {hyear=>1436}),
     _h_hijra     ({_expand_dm("14-10")}, {hyear=>1437}),
 
@@ -619,23 +619,30 @@ $year_holidays{2015} = [
     _jointlv     ({_expand_dm("24-12")}, {holiday=>$christmas}),
 ];
 
-# tentative
+# decreed jun 25, 2015
 #
 # ref:
 # - http://id.wikipedia.org/wiki/2016#Hari_libur_nasional_di_Indonesia
+# - http://www.merdeka.com/peristiwa/ini-daftar-hari-libur-nasional-dan-cuti-bersama-2016.html
 my $eidulf2016;
 $year_holidays{2016} = [
     _h_chnewyear ({_expand_dm("08-02")}, {hyear=>2567}),
     _h_nyepi     ({_expand_dm("09-03")}, {hyear=>1938}),
     _h_goodfri   ({_expand_dm("25-03")}),
-    _h_isramiraj ({_expand_dm("04-05")}),
     _h_ascension ({_expand_dm("05-05")}),
+    _h_isramiraj ({_expand_dm("06-05")}),
     _h_vesakha   ({_expand_dm("22-05")}, {hyear=>2560}),
-    _h_eidulf    ({_expand_dm("06-07")}, {hyear=>1437, day=>1}),
+    ($eidulf2015 =
+    _h_eidulf    ({_expand_dm("06-07")}, {hyear=>1437, day=>1})),
     _h_eidulf    ({_expand_dm("07-07")}, {hyear=>1437, day=>2}),
-    _h_eidula    ({_expand_dm("13-09")}, {hyear=>1437}),
-    _h_hijra     ({_expand_dm("03-10")}, {hyear=>1438}),
+    _h_eidula    ({_expand_dm("12-09")}, {hyear=>1437}),
+    _h_hijra     ({_expand_dm("02-10")}, {hyear=>1438}),
     _h_mawlid    ({_expand_dm("12-12")}),
+
+    _jointlv     ({_expand_dm("04-07")}, {holiday=>$eidulf2016}),
+    _jointlv     ({_expand_dm("05-07")}, {holiday=>$eidulf2016}),
+    _jointlv     ({_expand_dm("08-07")}, {holiday=>$eidulf2016}),
+    _jointlv     ({_expand_dm("26-12")}, {holiday=>$christmas}),
 ];
 
 
@@ -962,7 +969,7 @@ Calendar::Indonesia::Holiday - List Indonesian public holidays
 
 =head1 VERSION
 
-This document describes version 0.24 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2015-04-28.
+This document describes version 0.25 of Calendar::Indonesia::Holiday (from Perl distribution Calendar-Indonesia-Holiday), released on 2015-07-25.
 
 =head1 SYNOPSIS
 
@@ -1042,7 +1049,7 @@ days. If observe_joint_leaves is set to false, joint leave days are also counted
 as working days.
 
 Contains data from years 2002 to 2016 (joint leave days until
-2015).
+2016).
 
 Arguments ('*' denotes required arguments):
 
@@ -1094,7 +1101,7 @@ days. If observe_joint_leaves is set to false, joint leave days are also counted
 as working days.
 
 Contains data from years 2002 to 2016 (joint leave days until
-2015).
+2016).
 
 Arguments ('*' denotes required arguments):
 
@@ -1143,7 +1150,7 @@ List Indonesian holidays in calendar.
 List holidays and joint leave days ("cuti bersama").
 
 Contains data from years 2002 to 2016 (joint leave days until
-2015).
+2016).
 
 Arguments ('*' denotes required arguments):
 
